@@ -2,12 +2,12 @@
 /**
  * Mnemo external API interface.
  *
- * This file defines Mnemo's external API interface. Other applications can
+ * This file defines Mnemo's external API interface.  Other applications can
  * interact with Mnemo through this API.
  *
- * $Horde: mnemo/lib/api.php,v 1.53.2.7 2005/10/05 13:59:19 jan Exp $
+ * $Horde: mnemo/lib/api.php,v 1.53.2.18.2.3 2008/01/09 21:43:46 chuck Exp $
  *
- * Copyright 2001-2005 Horde Project (http://www.horde.org/)
+ * Copyright 2001-2007 Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -16,6 +16,20 @@
  * @package Mnemo
  */
 
+$_services['perms'] = array(
+    'args' => array(),
+    'type' => '{urn:horde}stringArray'
+);
+
+$_services['show'] = array(
+    'link' => '%application%/view.php?memolist=|notepad|&memo=|note|&uid=|uid|',
+);
+
+$_services['listNotepads'] = array(
+    'args' => array('owneronly' => 'boolean', 'permission' => 'int'),
+    'type' => '{urn:horde}stringArray',
+);
+
 $_services['list'] = array(
     'args' => array(),
     'type' => '{urn:horde}stringArray'
@@ -26,6 +40,11 @@ $_services['listBy'] = array(
     'type' => '{urn:horde}stringArray'
 );
 
+$_services['getActionTimestamp'] = array(
+    'args' => array('uid' => 'string', 'timestamp' => 'int'),
+    'type' => 'int',
+);
+
 $_services['import'] = array(
     'args' => array('content' => 'string', 'contentType' => 'string'),
     'type' => 'int'
@@ -47,13 +66,37 @@ $_services['replace'] = array(
 );
 
 
+function _mnemo_perms()
+{
+    $perms = array();
+    $perms['tree']['mnemo']['max_notes'] = false;
+    $perms['title']['mnemo:max_notes'] = _("Maximum Number of Notes");
+    $perms['type']['mnemo:max_notes'] = 'int';
+
+    return $perms;
+}
+
+/**
+ * @param boolean $owneronly   Only return notepads that this user owns?
+ *                             Defaults to false.
+ * @param integer $permission  The permission to filter notepads by.
+ *
+ * @return array  The notepads.
+ */
+function _mnemo_listNotepads($owneronly, $permission)
+{
+    require_once dirname(__FILE__) . '/base.php';
+
+    return Mnemo::listNotepads($owneronly, $permission);
+}
+
 /**
  * Returns an array of UIDs for all notes that the current user is
  * authorized to see.
  *
  * @return array  An array of UIDs for all notes the user can access.
  */
-function _mnemo_list()
+function _mnemo_list($notepad = null)
 {
     require_once dirname(__FILE__) . '/base.php';
     global $conf;
@@ -63,6 +106,19 @@ function _mnemo_list()
         return PEAR::raiseError('Not configured');
     }
 
+    /* Make sure we have a valid notepad. */
+    if (empty($notepad)) {
+        $notepad = Mnemo::getDefaultNotepad();
+    }
+
+    if (!array_key_exists($notepad,
+                          Mnemo::listNotepads(false, PERMS_READ))) {
+        return PEAR::raiseError(_("Permission Denied"));
+    }
+
+    /* Set notepad for listMemos. */
+    $GLOBALS['display_notepads'] = array($notepad);
+
     $memos = Mnemo::listMemos();
     if (is_a($memos, 'PEAR_Error')) {
         return $memos;
@@ -82,21 +138,59 @@ function _mnemo_list()
  *
  * @param string  $action     The action to check for - add, modify, or delete.
  * @param integer $timestamp  The time to start the search.
+ * @param string  $notepad    The notepad to search in.
  *
  * @return array  An array of UIDs matching the action and time criteria.
  */
-function &_mnemo_listBy($action, $timestamp)
+function _mnemo_listBy($action, $timestamp, $notepad = null)
 {
     require_once dirname(__FILE__) . '/base.php';
-    require_once 'Horde/History.php';
+
+    /* Make sure we have a valid notepad. */
+    if (empty($notepad)) {
+        $notepad = Mnemo::getDefaultNotepad();
+    }
+
+    if (!array_key_exists($notepad,
+                          Mnemo::listNotepads(false, PERMS_READ))) {
+        return PEAR::raiseError(_("Permission Denied"));
+    }
 
     $history = &Horde_History::singleton();
-    $histories = $history->getByTimestamp('>', $timestamp, array(array('op' => '=', 'field' => 'action', 'value' => $action)), 'mnemo');
+    $histories = $history->getByTimestamp('>', $timestamp, array(array('op' => '=', 'field' => 'action', 'value' => $action)), 'mnemo:' . $notepad);
     if (is_a($histories, 'PEAR_Error')) {
         return $histories;
     }
 
-    return array_keys($histories);
+    // Strip leading mnemo:username:.
+    return preg_replace('/^([^:]*:){2}/', '', array_keys($histories));
+}
+
+/**
+ * Returns the timestamp of an operation for a given uid an action.
+ *
+ * @param string $uid     The uid to look for.
+ * @param string $action  The action to check for - add, modify, or delete.
+ * @param string $notepad The notepad to search in.
+ *
+ * @return integer  The timestamp for this action.
+ */
+function _mnemo_getActionTimestamp($uid, $action, $notepad = null)
+{
+    require_once dirname(__FILE__) . '/base.php';
+
+    /* Make sure we have a valid notepad. */
+    if (empty($notepad)) {
+        $notepad = Mnemo::getDefaultNotepad();
+    }
+
+    if (!array_key_exists($notepad,
+                          Mnemo::listNotepads(false, PERMS_READ))) {
+        return PEAR::raiseError(_("Permission Denied"));
+    }
+
+    $history = &Horde_History::singleton();
+    return $history->getActionTimestamp('mnemo:' . $notepad . ':' . $uid, $action);
 }
 
 /**
@@ -175,7 +269,7 @@ function _mnemo_import($content, $contentType, $notepad = null)
         break;
 
     default:
-        return PEAR::raiseError(_("Unsupported Content-Type."));
+        return PEAR::raiseError(sprintf(_("Unsupported Content-Type: %s"),$contentType));
     }
 
     if (is_a($noteId, 'PEAR_Error')) {
@@ -190,17 +284,14 @@ function _mnemo_import($content, $contentType, $notepad = null)
  * Export a memo, identified by UID, in the requested contentType.
  *
  * @param string $uid          Identify the memo to export.
- * @param mixed  $contentType  What format should the data be in?
- *                             Either a string with one of:
- *                              'text/plain'
- *                              'text/x-vnote'
- *                             or an array with options:
- *                             'ContentType':  as above
- *                             'ENCODING': (optional) character encoding
- *                                         for strings fields
- *                             'CHARSET':  (optional) charset. Like UTF-8
+ * @param string $contentType  What format should the data be in?
+ *                             A string with one of:
+ *                             <pre>
+ *                               'text/plain'
+ *                               'text/x-vnote'
+ *                             </pre>
  *
- * @return string  The requested data.
+ * @return string  The requested data or PEAR_Error.
  */
 function _mnemo_export($uid, $contentType)
 {
@@ -212,18 +303,10 @@ function _mnemo_export($uid, $contentType)
         return $memo;
     }
 
-    if (!array_key_exists($memo['memolist_id'], Mnemo::listNotepads(false, PERMS_EDIT))) {
+    if (!array_key_exists($memo['memolist_id'], Mnemo::listNotepads(false, PERMS_READ))) {
         return PEAR::raiseError(_("Permission Denied"));
     }
 
-    if (is_array($contentType)) {
-        $options = $contentType;
-        $contentType = $options['ContentType'];
-        unset($options['ContentType']);
-    } else {
-        $options = array();
-    }
-
     switch ($contentType) {
     case 'text/plain':
         return $memo['body'];
@@ -233,23 +316,17 @@ function _mnemo_export($uid, $contentType)
         require_once 'Horde/iCalendar.php';
 
         // Create the new iCalendar container.
-        $iCal = &new Horde_iCalendar();
+        $iCal = &new Horde_iCalendar('1.1');
         $iCal->setAttribute('VERSION', '1.1');
         $iCal->setAttribute('PRODID', '-//The Horde Project//Mnemo ' . MNEMO_VERSION . '//EN');
         $iCal->setAttribute('METHOD', 'PUBLISH');
 
         // Create a new vNote.
         $vNote = $storage->toiCalendar($memo, $iCal);
-
-        // Set encoding options for all string values. For vNotes,
-        // just BODY.
-        $vNote->setParameter('BODY', $options);
-
         return $vNote->exportvCalendar();
-
-    default:
-        return PEAR::raiseError(_("Unsupported Content-Type."));
     }
+
+    return PEAR::raiseError(sprintf(_("Unsupported Content-Type: %s"),$contentType));
 }
 
 /**
@@ -340,6 +417,6 @@ function _mnemo_replace($uid, $content, $contentType)
                                 $note['body'],!empty($note['category']) ? $note['category'] : '');
 
     default:
-        return PEAR::raiseError(_("Unsupported Content-Type."));
+        return PEAR::raiseError(sprintf(_("Unsupported Content-Type: %s"),$contentType));
     }
 }
