@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: mnemo/memo.php,v 1.42.2.3 2005/08/23 11:24:54 jan Exp $
+ * $Horde: mnemo/memo.php,v 1.42.2.6 2007/01/02 13:55:10 jan Exp $
  *
- * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2007 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -29,6 +29,17 @@ if (is_null($actionID)) {
 /* Run through the action handlers. */
 switch ($actionID) {
 case 'add_memo':
+    /* Check permissions. */
+    if (Mnemo::hasPermission('max_notes') !== true &&
+        Mnemo::hasPermission('max_notes') <= Mnemo::countMemos()) {
+        $message = @htmlspecialchars(sprintf(_("You are not allowed to create more than %d notes."), Mnemo::hasPermission('max_notes')), ENT_COMPAT, NLS::getCharset());
+        if (!empty($conf['hooks']['permsdenied'])) {
+            $message = Horde::callHook('_perms_hook_denied', array('mnemo:max_notes'), 'horde', $message);
+        }
+        $notification->push($message, 'horde.error', array('content.raw'));
+        header('Location: ' . Horde::applicationUrl('list.php', true));
+        exit;
+    }
     /* Set up the note attributes. */
     $memolist_id = Mnemo::getDefaultNotepad();
     if (is_a($memolist_id, 'PEAR_Error')) {
@@ -79,20 +90,23 @@ case 'save_memo':
             }
         }
 
-        /* If $memo_id is set, we're modifying an existing note.
-         * Otherwise, we're adding a new note with the provided
-         * attributes. */
-        if (!empty($memo_id) && !is_a(Mnemo::getMemo($memolist_original, $memo_id), 'PEAR_Error')) {
+        /* If $memo_id is set, we're modifying an existing note.  Otherwise,
+         * we're adding a new note with the provided attributes. */
+        if (!empty($memo_id) &&
+            !is_a(Mnemo::getMemo($memolist_original, $memo_id), 'PEAR_Error')) {
             $storage = &Mnemo_Driver::singleton($memolist_original);
             $memo_desc = $storage->getMemoDescription($memo_body);
             $result = $storage->modify($memo_id, $memo_desc, $memo_body, $memo_category);
 
-            if (!is_a($result, 'PEAR_Error') && $memolist_original != $notepad_target) {
+            if (!is_a($result, 'PEAR_Error') &&
+                $memolist_original != $notepad_target) {
                 /* Moving the note to another notepad. */
                 $share = $GLOBALS['mnemo_shares']->getShare($memolist_original);
-                if (!is_a($share, 'PEAR_Error') && $share->hasPermission(Auth::getAuth(), PERMS_DELETE)) {
+                if (!is_a($share, 'PEAR_Error') &&
+                    $share->hasPermission(Auth::getAuth(), PERMS_DELETE)) {
                     $share = $GLOBALS['mnemo_shares']->getShare($notepad_target);
-                    if (!is_a($share, 'PEAR_Error') && $share->hasPermission(Auth::getAuth(), PERMS_EDIT)) {
+                    if (!is_a($share, 'PEAR_Error') &&
+                        $share->hasPermission(Auth::getAuth(), PERMS_EDIT)) {
                         $result = $storage->move($memo_id, $notepad_target);
                     } else {
                         $notification->push(_("Access denied moving the note."), 'horde.error');
@@ -102,6 +116,12 @@ case 'save_memo':
                 }
             }
         } else {
+            /* Check permissions. */
+            if (Mnemo::hasPermission('max_notes') !== true &&
+                Mnemo::hasPermission('max_notes') <= Mnemo::countMemos()) {
+                header('Location: ' . Horde::applicationUrl('list.php', true));
+                exit;
+            }
             /* Creating a new note. */
             $storage = &Mnemo_Driver::singleton($notepad_target);
             $memo_desc = $storage->getMemoDescription($memo_body);
@@ -128,7 +148,8 @@ case 'delete_memos':
 
     if (!is_null($memo_id) && Mnemo::getMemo($memolist_id, $memo_id)) {
         $share = $GLOBALS['mnemo_shares']->getShare($memolist_id);
-        if (!is_a($share, 'PEAR_Error') && $share->hasPermission(Auth::getAuth(), PERMS_DELETE)) {
+        if (!is_a($share, 'PEAR_Error') &&
+            $share->hasPermission(Auth::getAuth(), PERMS_DELETE)) {
             $storage = &Mnemo_Driver::singleton($memolist_id);
             $result = $storage->delete($memo_id);
 
