@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: mnemo/view.php,v 1.27.2.3 2005/08/23 11:24:54 jan Exp $
+ * $Horde: mnemo/view.php,v 1.27.2.8 2007/01/02 13:55:11 jan Exp $
  *
- * Copyright 2001-2005 Jon Parise <jon@horde.org>
+ * Copyright 2001-2007 Jon Parise <jon@horde.org>
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -15,12 +15,30 @@
 @define('MNEMO_BASE', dirname(__FILE__));
 require_once MNEMO_BASE . '/lib/base.php';
 
-/* If we aren't provided with a note,  redirect to the notepad view. */
-$memo_id = Util::getFormData('memo');
-$memolist_id = Util::getFormData('memolist');
-if (!isset($memo_id)) {
-    header('Location: ' . Horde::applicationUrl('list.php', true));
-    exit;
+/* We can either have a UID or a memo id and a notepad. Check for UID
+ * first. */
+if ($uid = Util::getFormData('uid')) {
+    $storage = &Mnemo_Driver::singleton();
+    $memo = $storage->getByUID($uid);
+    if (is_a($memo, 'PEAR_Error')) {
+        header('Location: ' . Horde::applicationUrl('list.php', true));
+        exit;
+    }
+
+    $memo_id = $memo['memo_id'];
+    $memolist_id = $memo['memolist_id'];
+} else {
+    /* If we aren't provided with a memo and memolist, redirect to
+     * list.php. */
+    $memo_id = Util::getFormData('memo');
+    $memolist_id = Util::getFormData('memolist');
+    if (!isset($memo_id) || !$memolist_id) {
+        header('Location: ' . Horde::applicationUrl('list.php', true));
+        exit;
+    }
+
+    /* Get the current memo. */
+    $memo = Mnemo::getMemo($memolist_id, $memo_id);
 }
 
 $share = $GLOBALS['mnemo_shares']->getShare($memolist_id);
@@ -34,9 +52,6 @@ if (is_a($share, 'PEAR_Error')) {
     exit;
 }
 
-/* Get the current note. */
-$memo = Mnemo::getMemo($memolist_id, $memo_id);
-
 /* If the requested note doesn't exist, display an error message. */
 if (!$memo || !isset($memo['memo_id'])) {
     $notification->push(_("Note not found."), 'horde.error');
@@ -48,15 +63,17 @@ if (!$memo || !isset($memo['memo_id'])) {
 if (!empty($memo['uid'])) {
     $history = &Horde_History::singleton();
     $log = $history->getHistory('mnemo:' . $memolist_id . ':' . $memo['uid']);
-    foreach ($log->getData() as $entry) {
-        switch ($entry['action']) {
-        case 'add':
-            $created = $entry['ts'];
-            break;
+    if ($log && !is_a($log, 'PEAR_Error')) {
+        foreach ($log->getData() as $entry) {
+            switch ($entry['action']) {
+            case 'add':
+                $created = $entry['ts'];
+                break;
 
-        case 'modify':
-            $modified = $entry['ts'];
-            break;
+            case 'modify':
+                $modified = $entry['ts'];
+                break;
+            }
         }
     }
 }
@@ -76,6 +93,7 @@ if ($print_view) {
                                                        'memolist' => $memolist_id,
                                                        'print' => 'true'));
     $print_link = Horde::url($print_link);
+    Horde::addScriptFile('stripe.js', 'horde', true);
     require MNEMO_TEMPLATES . '/menu.inc';
 }
 
